package com.ruoyi.project.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.mapper.TrsNamenmgWordsMapper;
import com.ruoyi.project.domain.TrsNamenmgWords;
import com.ruoyi.project.service.ITrsNamenmgWordsService;
import com.ruoyi.common.core.text.Convert;

/**
 * 内蒙古自治区领导人词库Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-04-20
 */
@Service
public class TrsNamenmgWordsServiceImpl implements ITrsNamenmgWordsService 
{
    @Autowired
    private TrsNamenmgWordsMapper trsNamenmgWordsMapper;

    /**
     * 查询内蒙古自治区领导人词库
     * 
     * @param id 内蒙古自治区领导人词库主键
     * @return 内蒙古自治区领导人词库
     */
    @Override
    public TrsNamenmgWords selectTrsNamenmgWordsById(Long id)
    {
        return trsNamenmgWordsMapper.selectTrsNamenmgWordsById(id);
    }

    /**
     * 查询内蒙古自治区领导人词库列表
     * 
     * @param trsNamenmgWords 内蒙古自治区领导人词库
     * @return 内蒙古自治区领导人词库
     */
    @Override
    public List<TrsNamenmgWords> selectTrsNamenmgWordsList(TrsNamenmgWords trsNamenmgWords)
    {
        return trsNamenmgWordsMapper.selectTrsNamenmgWordsList(trsNamenmgWords);
    }

    /**
     * 新增内蒙古自治区领导人词库
     * 
     * @param trsNamenmgWords 内蒙古自治区领导人词库
     * @return 结果
     */
    @Override
    public int insertTrsNamenmgWords(TrsNamenmgWords trsNamenmgWords)
    {
        return trsNamenmgWordsMapper.insertTrsNamenmgWords(trsNamenmgWords);
    }

    /**
     * 修改内蒙古自治区领导人词库
     * 
     * @param trsNamenmgWords 内蒙古自治区领导人词库
     * @return 结果
     */
    @Override
    public int updateTrsNamenmgWords(TrsNamenmgWords trsNamenmgWords)
    {
        return trsNamenmgWordsMapper.updateTrsNamenmgWords(trsNamenmgWords);
    }

    /**
     * 批量删除内蒙古自治区领导人词库
     * 
     * @param ids 需要删除的内蒙古自治区领导人词库主键
     * @return 结果
     */
    @Override
    public int deleteTrsNamenmgWordsByIds(String ids)
    {
        return trsNamenmgWordsMapper.deleteTrsNamenmgWordsByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除内蒙古自治区领导人词库信息
     * 
     * @param id 内蒙古自治区领导人词库主键
     * @return 结果
     */
    @Override
    public int deleteTrsNamenmgWordsById(Long id)
    {
        return trsNamenmgWordsMapper.deleteTrsNamenmgWordsById(id);
    }
}
